@@ -1,5 +1,7 @@
 """
-Main interface for identitystore service client
+Type annotations for identitystore service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_identitystore/client.html)
 
 Usage::
 
@@ -44,7 +46,8 @@ class Exceptions:
 
 class IdentityStoreClient:
     """
-    [IdentityStore.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/identitystore.html#IdentityStore.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/identitystore.html#IdentityStore.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_identitystore/client.html)
     """
 
     meta: ClientMeta
@@ -52,17 +55,20 @@ class IdentityStoreClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/identitystore.html#IdentityStore.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/identitystore.html#IdentityStore.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_identitystore/client.html#can-paginate)
         """
 
     def describe_group(self, IdentityStoreId: str, GroupId: str) -> DescribeGroupResponseTypeDef:
         """
-        [Client.describe_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/identitystore.html#IdentityStore.Client.describe_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/identitystore.html#IdentityStore.Client.describe_group)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_identitystore/client.html#describe-group)
         """
 
     def describe_user(self, IdentityStoreId: str, UserId: str) -> DescribeUserResponseTypeDef:
         """
-        [Client.describe_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/identitystore.html#IdentityStore.Client.describe_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/identitystore.html#IdentityStore.Client.describe_user)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_identitystore/client.html#describe-user)
         """
 
     def generate_presigned_url(
@@ -73,7 +79,8 @@ class IdentityStoreClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/identitystore.html#IdentityStore.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/identitystore.html#IdentityStore.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_identitystore/client.html#generate-presigned-url)
         """
 
     def list_groups(
@@ -84,7 +91,8 @@ class IdentityStoreClient:
         Filters: List[FilterTypeDef] = None,
     ) -> ListGroupsResponseTypeDef:
         """
-        [Client.list_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/identitystore.html#IdentityStore.Client.list_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/identitystore.html#IdentityStore.Client.list_groups)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_identitystore/client.html#list-groups)
         """
 
     def list_users(
@@ -95,5 +103,6 @@ class IdentityStoreClient:
         Filters: List[FilterTypeDef] = None,
     ) -> ListUsersResponseTypeDef:
         """
-        [Client.list_users documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/identitystore.html#IdentityStore.Client.list_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/identitystore.html#IdentityStore.Client.list_users)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_identitystore/client.html#list-users)
         """
